package MojoMojo::Schema::Base::Result;

use strict;
use warnings;
use parent qw/DBIx::Class/;

=head1 NAME

MojoMojo::Schema::Base::Result

=head1 DESCRIPTION

Base class for all result classes below the MojoMojo::Schema::Result::* namespace.

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
